from distutils.core import setup

setup(
	name = 'neast',
	version = '1.0.0',
	py_modules = ['neast'],
	author = 'xudasong',
	author_email = 'xudsong@163.com',
	url = 'http://www.headfirstlabs.com',
	description = 'A simple printer of neast lists',
	)